optimise: Optimise Calibration Series

View source: R/optimise.R

optimiseR Documentation

Optimise Calibration Series

Description

Optimise Calibration Series

Usage

optimise(calibration_data, p = 0.6, quad = TRUE)

Arguments

calibration_data

a data.frame or tibble of calibration data. The data should have two columns named, area and concentration.

p

a numeric value (between 0 and 1) of the minimum percentage of calibration observations to utilise

quad

logical; if TRUE then quadratic regression is also included alongside linear regression duringf the optimisation

Value

a list of three elements.

  • type: a character string of the regression type (linear or quadratic)

  • score: numeric value of the OptiCal score

  • data: a data.frame of the optimal set of calibration observations


wilsontom/OptiCal documentation built on March 24, 2022, 1:20 p.m.